@@ -1,7 +1,6 @@
-import urlparse
-
 class MutableJenkinsThing(object):
     """
+    A mixin for certain mutable objects which can be renamed and deleted.
     """
     def get_delete_url(self):
         return '%s/doDelete' % self.baseurl
